# Changelog

All notable changes to this project will be documented in this file.

## [0.1.6](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.5...v0.1.6) (2026-03-23)


### Bug Fixes

* restore full release flow for manual reruns ([#58](https://github.com/zhixiangli/fast-bpe-rs/issues/58)) ([059bbe2](https://github.com/zhixiangli/fast-bpe-rs/commit/059bbe29eb20aa3448ab731915be8c007b9ea1f5))

## [0.1.5](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.4...v0.1.5) (2026-03-21)


### Bug Fixes

* prevent duplicate release PRs by removing draft release config ([#42](https://github.com/zhixiangli/fast-bpe-rs/issues/42)) ([b5c0987](https://github.com/zhixiangli/fast-bpe-rs/commit/b5c098713c2d156687ad800ba61bd53e1342a489))

## [0.1.4](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.3...v0.1.4) (2026-03-21)


### Bug Fixes

* handle invalid split regex in python bindings ([#7](https://github.com/zhixiangli/fast-bpe-rs/issues/7)) ([151d0c1](https://github.com/zhixiangli/fast-bpe-rs/commit/151d0c17c1f40d127cb74dd7de69fe2324603a4b))
* normalize python unicode decode errors ([#9](https://github.com/zhixiangli/fast-bpe-rs/issues/9)) ([0d4c063](https://github.com/zhixiangli/fast-bpe-rs/commit/0d4c063080ade3919c12823d32529371f4da240b))
* set release to draft before uploading assets on retry ([#37](https://github.com/zhixiangli/fast-bpe-rs/issues/37)) ([3d45a36](https://github.com/zhixiangli/fast-bpe-rs/commit/3d45a36790160494e6fe951ab6dde99bcbf18927))

## [0.1.3](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.2...v0.1.3) (2026-03-21)


### Bug Fixes

* set release to draft before uploading assets on retry ([#37](https://github.com/zhixiangli/fast-bpe-rs/issues/37)) ([3d45a36](https://github.com/zhixiangli/fast-bpe-rs/commit/3d45a36790160494e6fe951ab6dde99bcbf18927))

## [0.1.2](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.1...v0.1.2) (2026-03-21)


### Bug Fixes

* handle invalid split regex in python bindings ([#7](https://github.com/zhixiangli/fast-bpe-rs/issues/7)) ([151d0c1](https://github.com/zhixiangli/fast-bpe-rs/commit/151d0c17c1f40d127cb74dd7de69fe2324603a4b))
* normalize python unicode decode errors ([#9](https://github.com/zhixiangli/fast-bpe-rs/issues/9)) ([0d4c063](https://github.com/zhixiangli/fast-bpe-rs/commit/0d4c063080ade3919c12823d32529371f4da240b))

## [0.1.1](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.0...v0.1.1) (2026-03-21)


### Bug Fixes

* handle invalid split regex in python bindings ([#7](https://github.com/zhixiangli/fast-bpe-rs/issues/7)) ([151d0c1](https://github.com/zhixiangli/fast-bpe-rs/commit/151d0c17c1f40d127cb74dd7de69fe2324603a4b))
* normalize python unicode decode errors ([#9](https://github.com/zhixiangli/fast-bpe-rs/issues/9)) ([0d4c063](https://github.com/zhixiangli/fast-bpe-rs/commit/0d4c063080ade3919c12823d32529371f4da240b))

## [0.1.0] - 2026-03-21

### Miscellaneous Chores

* Initial release.
